@@ -8,7 +8,9 @@ struct MyState {
 fn main() {
     rui(state(MyState { value: [0.0, 0.0] }, |state| {
         vstack((
-            text(&format!("value: {:?}", state.get().value)).padding(Auto),
+            text(&format!("value: {:?}", state.get().value))
+                .font_size(10)
+                .padding(Auto),
             hslider(bind!(state, value[0]))
                 .thumb_color(RED_HIGHLIGHT)
                 .padding(Auto),
