@@ -14,9 +14,9 @@ pub type WorldPoint = Point2D<f32, WorldSpace>;
 
 use std::collections::hash_map::DefaultHasher;
 use std::hash::{Hash, Hasher};
+use std::sync::{Arc, Mutex};
 
-use std::cell::RefCell;
-use std::rc::Rc;
+use tao::event_loop::EventLoopProxy;
 
 /// `ViewID` is a unique identifier for a view. We're using a u64 and hashing
 /// under the assumption there won't be collsions. The underlying u64 is a function
@@ -49,6 +49,18 @@ pub struct LayoutBox {
     pub offset: LocalOffset,
 }
 
+// This could use a better name.
+pub struct Dirty {
+    pub dirty: bool,
+    pub event_loop_proxy: Option<EventLoopProxy<()>>
+}
+
+impl Dirty {
+    pub fn new(event_loop_proxy: Option<EventLoopProxy<()>>) -> Self {
+        Dirty{ dirty: false, event_loop_proxy }
+    }
+}
+
 /// The Context stores all UI state. A user of the library
 /// shouldn't have to interact with it directly.
 pub struct Context {
@@ -77,11 +89,11 @@ pub struct Context {
     pub focused_id: Option<ViewID>,
 
     /// Did state change?
-    pub dirty: Rc<RefCell<bool>>,
+    pub dirty: Arc<Mutex<Dirty>>,
 }
 
 impl Context {
-    pub fn new() -> Self {
+    pub fn new(event_loop_proxy: Option<EventLoopProxy<()>>) -> Self {
         Self {
             state_map: HashMap::new(),
             layout: HashMap::new(),
@@ -91,7 +103,7 @@ impl Context {
             previous_position: [LocalPoint::zero(); 16],
             root_id: ViewID::default(),
             focused_id: None,
-            dirty: Rc::new(RefCell::new(false)),
+            dirty: Arc::new(Mutex::new(Dirty::new(event_loop_proxy))),
         }
     }
 
