@@ -268,7 +268,7 @@ fn build_menubar(
     make_menu_rec(&items, 0, command_map)
 }
 
-/// Call this function to describe your UI.
+/// Call this function to run your UI.
 pub fn rui(view: impl View + 'static) {
     let event_loop = EventLoop::new();
 
@@ -292,7 +292,7 @@ pub fn rui(view: impl View + 'static) {
     surface.configure(&device, &config);
 
     let mut vger = VGER::new(&device, wgpu::TextureFormat::Bgra8UnormSrgb);
-    let mut cx = Context::new();
+    let mut cx = Context::new(Some(event_loop.create_proxy()));
     let mut mouse_position = LocalPoint::zero();
 
     let mut commands = Vec::new();
@@ -335,6 +335,9 @@ pub fn rui(view: impl View + 'static) {
                 surface.configure(&device, &config);
                 window.request_redraw();
             }
+            event::Event::UserEvent(_) => {
+                println!("received user event");
+            }
             event::Event::MainEventsCleared => {
                 // Application update code.
 
@@ -343,7 +346,7 @@ pub fn rui(view: impl View + 'static) {
                 // You only need to call this if you've determined that you need to redraw, in
                 // applications which do not always need to. Applications that redraw continuously
                 // can just render here instead.
-                if *cx.dirty.borrow() {
+                if cx.dirty.lock().unwrap().dirty {
                     // Have the commands changed?
                     let mut new_commands = Vec::new();
                     view.commands(cx.root_id, &mut cx, &mut new_commands);
@@ -358,7 +361,7 @@ pub fn rui(view: impl View + 'static) {
 
                     window.request_redraw();
 
-                    *cx.dirty.borrow_mut() = false;
+                    cx.dirty.lock().unwrap().dirty = false;
                 }
             }
             event::Event::RedrawRequested(_) => {
@@ -490,12 +493,11 @@ pub fn rui(view: impl View + 'static) {
 mod tests {
 
     use super::*;
-    use std::cell::RefCell;
-    use std::rc::Rc;
+    use std::sync::{Arc, Mutex};
 
     #[test]
     fn test_state_clone() {
-        let d = Rc::new(RefCell::new(false));
+        let d = Arc::new(Mutex::new(Dirty::new(None)));
         let s = State::new(0, d);
         let s2 = s.clone();
         s.set(42);
@@ -516,7 +518,7 @@ mod tests {
 
     #[test]
     fn test_state2() {
-        let mut cx = Context::new();
+        let mut cx = Context::new(None);
         let v = counter(42);
         v.print(ViewID::default(), &mut cx);
     }
@@ -568,7 +570,7 @@ mod tests {
 
     #[test]
     fn test_bind() {
-        let dirty = Rc::new(RefCell::new(false));
+        let dirty = Arc::new(Mutex::new(Dirty::new(None)));
         let s = State::new(BindingTestData { x: 0 }, dirty);
         let b = bind!(s, x);
         b.set(42);
