@@ -1,5 +1,4 @@
-use std::cell::RefCell;
-use std::rc::Rc;
+use std::sync::{Arc, Mutex};
 
 use crate::*;
 
@@ -7,19 +6,19 @@ struct Holder<S> {
     value: S,
 
     /// Has the state changed since the last redraw?
-    dirty: Rc<RefCell<bool>>,
+    dirty: Arc<Mutex<Dirty>>,
 }
 
 /// Contains application state. Application state is created using `state`.
 #[derive(Clone)]
 pub struct State<S> {
-    value: Rc<RefCell<Holder<S>>>,
+    value: Arc<Mutex<Holder<S>>>,
 }
 
 impl<S> State<S> {
-    pub fn new(value: S, dirty: Rc<RefCell<bool>>) -> Self {
+    pub fn new(value: S, dirty: Arc<Mutex<Dirty>>) -> Self {
         Self {
-            value: Rc::new(RefCell::new(Holder { value, dirty })),
+            value: Arc::new(Mutex::new(Holder { value, dirty })),
         }
     }
 }
@@ -28,14 +27,23 @@ impl<S> Binding<S> for State<S>
 where
     S: Clone + 'static,
 {
-    fn with<T, F: Fn(&S) -> T>(&self, f: F) -> T {
-        f(&self.value.borrow().value)
+    fn with<T, F: FnOnce(&S) -> T>(&self, f: F) -> T {
+        f(&self.value.lock().unwrap().value)
     }
-    fn with_mut<T, F: Fn(&mut S) -> T>(&self, f: F) -> T {
-        let mut holder = self.value.borrow_mut();
+    fn with_mut<T, F: FnOnce(&mut S) -> T>(&self, f: F) -> T {
+        let mut holder = self.value.lock().unwrap();
         // Set dirty so the view tree will be redrawn.
-        *holder.dirty.borrow_mut() = true;
-        f(&mut holder.value)
+        holder.dirty.lock().unwrap().dirty = true;
+        let t = f(&mut holder.value);
+
+        // Wake up the event loop.
+        if let Some(proxy) = &holder.dirty.lock().unwrap().event_loop_proxy {
+            if let Err(err) = proxy.send_event( () ) {
+                println!("error waking up event loop: {:?}", err);
+            }
+        }
+
+        t
     }
 }
 
